==> tabular-data-gwt-service-2.0.0-20140226.114308-133-servicearchive.tar.gz: org/gcube/portlets/user/td/gwtservice/shared/tr/column/type/ChangeColumnTypeSession.java <==
package org.gcube.portlets.user.td.gwtservice.shared.tr.column.type;

import java.io.Serializable;

import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnDataType;
import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnTypeCode;

public class ChangeColumnTypeSession implements Serializable {

	private static final long serialVersionUID = 7154832921853261421L;
	
	protected ColumnData columnData;
	protected ColumnTypeCode columnTypeCode;
	protected ColumnDataType columnDataType;
	protected ColumnTypeCode columnTypeCodeTarget;
	protected ColumnDataType columnDataTypeTarget;
	
	
	
	public ColumnTypeCode getColumnTypeCode() {
		return columnTypeCode;
	}
	public void setColumnTypeCode(ColumnTypeCode columnTypeCode) {
		this.columnTypeCode = columnTypeCode;
	}
	public ColumnDataType getColumnDataType() {
		return columnDataType;
	}
	public void setColumnDataType(ColumnDataType columnDataType) {
		this.columnDataType = columnDataType;
	}
	public ColumnTypeCode getColumnTypeCodeTarget() {
		return columnTypeCodeTarget;
	}
	public void setColumnTypeCodeTarget(ColumnTypeCode columnTypeCodeTarget) {
		this.columnTypeCodeTarget = columnTypeCodeTarget;
	}
	public ColumnDataType getColumnDataTypeTarget() {
		return columnDataTypeTarget;
	}
	public void setColumnDataTypeTarget(ColumnDataType columnDataTypeTarget) {
		this.columnDataTypeTarget = columnDataTypeTarget;
	}
	public ColumnData getColumnData() {
		return columnData;
	}
	public void setColumnData(ColumnData columnData) {
		this.columnData = columnData;
	}
	@Override
	public String toString() {
		return "ChangeColumnTypeSession [columnData=" + columnData
				+ ", columnTypeCode=" + columnTypeCode + ", columnDataType="
				+ columnDataType + ", columnTypeCodeTarget="
				+ columnTypeCodeTarget + ", columnDataTypeTarget="
				+ columnDataTypeTarget + "]";
	}
	
	
	
	
	
	
}

==> tabular-data-gwt-service-2.2.0-20140625.133905-105-servicearchive.tar.gz: org/gcube/portlets/user/td/gwtservice/shared/tr/column/type/ChangeColumnTypeSession.java <==
package org.gcube.portlets.user.td.gwtservice.shared.tr.column.type;

import java.io.Serializable;

import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnDataType;
import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnTypeCode;
import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.TimeDimensionType;

public class ChangeColumnTypeSession implements Serializable {

	private static final long serialVersionUID = 7154832921853261421L;

	protected ColumnData columnData;
	protected ColumnTypeCode columnTypeCode;
	protected ColumnDataType columnDataType;
	protected ColumnTypeCode columnTypeCodeTarget;
	protected ColumnDataType columnDataTypeTarget;
	protected String locale;
	
	protected TimeDimensionType timeDimensionType;
	protected ColumnData codelistColumnReference;

	public ColumnTypeCode getColumnTypeCode() {
		return columnTypeCode;
	}

	public void setColumnTypeCode(ColumnTypeCode columnTypeCode) {
		this.columnTypeCode = columnTypeCode;
	}

	public ColumnDataType getColumnDataType() {
		return columnDataType;
	}

	public void setColumnDataType(ColumnDataType columnDataType) {
		this.columnDataType = columnDataType;
	}

	public ColumnTypeCode getColumnTypeCodeTarget() {
		return columnTypeCodeTarget;
	}

	public void setColumnTypeCodeTarget(ColumnTypeCode columnTypeCodeTarget) {
		this.columnTypeCodeTarget = columnTypeCodeTarget;
	}

	public ColumnDataType getColumnDataTypeTarget() {
		return columnDataTypeTarget;
	}

	public void setColumnDataTypeTarget(ColumnDataType columnDataTypeTarget) {
		this.columnDataTypeTarget = columnDataTypeTarget;
	}

	public ColumnData getColumnData() {
		return columnData;
	}

	public void setColumnData(ColumnData columnData) {
		this.columnData = columnData;
	}

	public ColumnData getCodelistColumnReference() {
		return codelistColumnReference;
	}

	public void setCodelistColumnReference(ColumnData codelistColumnReference) {
		this.codelistColumnReference = codelistColumnReference;
	}

	public TimeDimensionType getTimeDimensionType() {
		return timeDimensionType;
	}

	public void setTimeDimensionType(TimeDimensionType timeDimensionType) {
		this.timeDimensionType = timeDimensionType;
	}

	public String getLocale() {
		return locale;
	}

	public void setLocale(String locale) {
		this.locale = locale;
	}

	@Override
	public String toString() {
		return "ChangeColumnTypeSession [columnData=" + columnData
				+ ", columnTypeCode=" + columnTypeCode + ", columnDataType="
				+ columnDataType + ", columnTypeCodeTarget="
				+ columnTypeCodeTarget + ", columnDataTypeTarget="
				+ columnDataTypeTarget + ", locale=" + locale
				+ ", timeDimensionType=" + timeDimensionType
				+ ", codelistColumnReference=" + codelistColumnReference + "]";
	}

	
}
